@@ -5,10 +5,13 @@ from decimal import Decimal
 
 from peak.rules import abstract, around, when
 
+# simplejson is actually available as json in the standard library
+# since Python 2.6, but the externally maintained package is newer
+# and can be substantially faster, so we try to import this first
 try:
-    from json import JSONEncoder
-except ImportError: # Python < 2.6
-    from simplejson import JSONEncoder
+    from simplejson import JSONEncoder # externally maintained version
+except ImportError:
+    from json import JSONEncoder # standard lib version
 
 __all__ = ['jsonify', 'encode', 'encode_iter']
 
@@ -25,7 +28,7 @@ def jsonify(obj):
 
     Specific functions should return a string or an object that can be
     serialized with JSON, i.e., it is made up of only lists, dictionaries
-    (with string keys), and strings, ints, and floats.
+    (with string keys), strings, ints, and floats.
 
     """
     return jsonify_default(obj)
