@@ -1,6 +1,8 @@
 """Template support for JSON"""
 
-from turbojson import jsonify
+from turbojson.jsonify import GenericJSON
+
+__all__ = ['JsonSupport']
 
 
 class JsonSupport(object):
@@ -19,7 +21,7 @@ class JsonSupport(object):
                 if opt == 'assume_encoding':
                     opt = 'encoding'
                 opts[opt] = options[option]
-        self.encoder = jsonify.GenericJSON(**opts)
+        self.encoder = GenericJSON(**opts)
 
     def render(self, info, format=None, fragment=False, template=None):
         """Renders data in the desired format.
@@ -35,7 +37,7 @@ class JsonSupport(object):
 
         """
         for item in info.keys():
-            if item.startswith("tg_") and item != "tg_flash":
+            if item.startswith('tg_') and item != 'tg_flash':
                 del info[item]
         output = self.encoder.encode(info)
         if isinstance(output, unicode):
